@@ -16,14 +16,14 @@
 #ifndef __XCM_VERSION_H__
 #define __XCM_VERSION_H__
 
-#define HAVE_X11 1
-#define HAVE_LINUX 1
+#define XCM_HAVE_X11 1
+#define XCM_HAVE_LINUX 1
 
 #define XCM_VERSION_MAJOR 0
 #define XCM_VERSION_MINOR 5
-#define XCM_VERSION_MICRO 0
-#define XCM_VERSION       0.5.0
-#define XCM_VERSION_NUM   (0*10000+5*100+0)
+#define XCM_VERSION_MICRO 2
+#define XCM_VERSION       0.5.2
+#define XCM_VERSION_NUM   (0*10000+5*100+2)
 #define XCM_LIB_VERSION   0:5:0
 
 #endif /* __XCM_VERSION_H__ */
